LocalizationController class
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
String> - LocalizationController
Properties
- currentLanguage → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translations
→ Map<
String, Map< String, String> > -
no setter
- value ↔ String
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
changeLanguage(
String newLang) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
init(
Map< String, Map< appTranslations, {String defaultLanguage = 'english'}) → voidString, String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → LocalizationController
-
final